package com.cultural.heritage.aop;

import jakarta.servlet.http.HttpServletRequest;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import java.lang.reflect.Method;
import java.util.Set;

@Component
@Aspect
public class AopConfig {

    @Pointcut("@annotation(com.cultural.heritage.aop.HasRole)")
    public void pointcut(){}

    @Before("pointcut()")
    public void before(JoinPoint joinPoint) {
        System.out.println("before-----------------");

        //获取到HttpServletRequest
        RequestAttributes requestAttributes = RequestContextHolder.getRequestAttributes();
        ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes) requestAttributes;
        HttpServletRequest request = servletRequestAttributes.getRequest();

        String username = request.getParameter("username");

        //获取当前用户角色的集合
        Set<String> userRoles = CacheManager.USER_ROLE_MAP.get(username);

        //获取当前请求的方法的签名
        MethodSignature signature = (MethodSignature) joinPoint.getSignature();

        //反射获取当前被调用的方法
        Method method = signature.getMethod();

        //判断当前方法是否有hasRole注解
        //如果有，判断用户是否具有注解属性中要求的角色
        //如果没有hasRole注解，那么说明方法不需要判断用户的角色，可以匿名访问

        HasRole hasRole = method.getDeclaredAnnotation(HasRole.class);
        if (hasRole != null && (userRoles != null || !userRoles.contains(hasRole.value()))) {
            throw new RuntimeException("用户没有访问的权限");
        }

    }
}
